@@ -1,7 +1,7 @@
 /* Bluefish HTML Editor
  * bftextview2_langmgr.c
  *
- * Copyright (C) 2008,2009,2010,2011,2012,2013 Olivier Sessink
+ * Copyright (C) 2008,2009,2010,2011,2012,2013,2014 Olivier Sessink
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -487,6 +487,9 @@ parse_attributes(Tbflang *bflang,xmlTextReaderPtr reader, Tattrib *attribs, gint
 	while (xmlTextReaderMoveToNextAttribute(reader)) {
 		gint i;
 		xmlChar *aname = xmlTextReaderName(reader);
+/*#ifdef DEVELOPMENT
+		g_print("parse_attributes, name=%s\n",aname);
+#endif*/
 		for (i=0;i<num_attribs;i++) {
 			if (xmlStrEqual(aname, (xmlChar *)attribs[i].name)) {
 				gchar *value = (gchar *)xmlTextReaderValue(reader);
@@ -748,13 +751,13 @@ process_scanning_element(xmlTextReaderPtr reader, Tbflangparsing * bfparser, gin
 						 gint ih_case_insens, gint ih_is_regex, GSList *ih_autocomplete)
 {
 	guint16 matchnum = 0;
-	gboolean add_element;
+	gboolean add_element, used_idref=FALSE;
 	gchar *pattern = NULL, *idref = NULL, *highlight = NULL, *blockstartelement = NULL, *blockhighlight =
-		NULL, *block_name = NULL, *class = NULL, *notclass = NULL, *id =	NULL;
+		NULL, *block_name = NULL, *class = NULL, *notclass = NULL, *id =	NULL, *condition_idref=NULL, *condition_contextref=NULL;
 	gboolean starts_block = FALSE, ends_block = FALSE, is_empty, tagclose_from_blockstack = FALSE, stretch_blockstart=FALSE;
 	gint case_insens = UNDEFINED, is_regex = UNDEFINED;
 	gint ends_context = 0;
-	gint identifier_mode=0, identifier_jump=0, identifier_autocomp=0;
+	gint identifier_mode=0, identifier_jump=0, identifier_autocomp=0,condition_mode=0,condition_relation=0;
 	GSList *autocomplete=NULL;
 	is_empty = xmlTextReaderIsEmptyElement(reader);
 
@@ -776,9 +779,19 @@ process_scanning_element(xmlTextReaderPtr reader, Tbflangparsing * bfparser, gin
 					{"stretch_blockstart", &stretch_blockstart, attribtype_int},
 					{"identifier_mode", &identifier_mode, attribtype_int},
 					{"identifier_jump", &identifier_jump, attribtype_int},
-					{"identifier_autocomp", &identifier_autocomp, attribtype_int}
+					{"identifier_autocomp", &identifier_autocomp, attribtype_int},
+					{"condition_blockstartidref", &condition_idref, attribtype_string},
+					{"condition_contextref", &condition_contextref, attribtype_string},
+					{"condition_mode", &condition_mode, attribtype_int},
+					{"condition_relation", &condition_relation, attribtype_int},
 					};
-	parse_attributes(bfparser->bflang,reader, attribs, 19);
+	parse_attributes(bfparser->bflang,reader, attribs, 23);
+#ifdef DEVELOPMENT
+/*	if (g_strcmp0(id,"e.css.in_style_attribute.dquote")==0) {
+		g_print("e.css.in_style_attribute.dquote has condition_mode=%d and contextref=%s\n",condition_mode,condition_contextref);
+	}*/
+#endif
+
 	if (stretch_blockstart && ends_block) {
 		g_print("Error in language file, id %s / pattern %s has mutually exclusive options stretch_blockstart and ends_block both enabled\n", id?id:"-", pattern?pattern:"null");
 		stretch_blockstart = FALSE;
@@ -789,13 +802,14 @@ process_scanning_element(xmlTextReaderPtr reader, Tbflangparsing * bfparser, gin
 	add_element = do_parse(bfparser, class, notclass);
 /*	g_print("add_element=%d for class=%s and notclass=%s\n",add_element, class, notclass);*/
 	if (add_element) {
-		if (idref && idref[0] && !id && !pattern) {
+		if (idref && idref[0]) {
 			guint16 matchnum;
 			matchnum = GPOINTER_TO_INT(g_hash_table_lookup(bfparser->patterns, idref));
-			if (!matchnum) {
+			if (!matchnum && !pattern) {
 				g_print("Error in language file, element with id %s does not exist\n", idref);
-			} else {
+			} else if (matchnum) {
 				compile_existing_match(bfparser->st, matchnum, context);
+				used_idref=TRUE;
 				if (g_array_index(bfparser->st->matches, Tpattern, matchnum).nextcontext < 0
 					&& (-1 * g_array_index(bfparser->st->matches, Tpattern, matchnum).nextcontext) >=
 					g_queue_get_length(contextstack)) {
@@ -805,7 +819,8 @@ process_scanning_element(xmlTextReaderPtr reader, Tbflangparsing * bfparser, gin
 				}
 
 			}
-		} else if (pattern && pattern[0]) {
+		}
+		if (!used_idref && pattern && pattern[0]) {
 			gchar *reference = NULL;
 			gboolean foldable=TRUE;
 			guint16 blockstartelementum = 0, nextcontext = 0;
@@ -852,12 +867,24 @@ process_scanning_element(xmlTextReaderPtr reader, Tbflangparsing * bfparser, gin
 								 identifier_mode,
 								 identifier_jump,
 								 identifier_autocomp);
+			if (condition_mode!= 0) {
+				gchar *refname=NULL;
+				if (condition_mode ==1 || condition_mode == 2) {
+					refname = condition_contextref;
+				} else if (condition_mode ==1 || condition_mode == 2) {
+					refname = condition_idref;
+				}
+				DBG_PARSING("condition_mode=%d, call pattern_set_condition, refname %s, contextref=%s\n",condition_mode,refname,condition_contextref);
+				pattern_set_condition(bfparser->st, matchnum, refname, condition_relation, condition_mode);
+			}
+
 			DBG_PARSING("add matchnum %d to hash table for key %s, starts_block=%d\n", matchnum, pattern,
 						starts_block);
 			g_hash_table_insert(bfparser->patterns, g_strdup(id ? id : pattern),
 								GINT_TO_POINTER((gint) matchnum));
 			/* now check if there is a deeper context */
 			if (!is_empty) {
+				gboolean processed_context=FALSE;
 				while (xmlTextReaderRead(reader) == 1) {
 					xmlChar *name;
 					int nodetype = xmlTextReaderNodeType(reader);
@@ -866,9 +893,13 @@ process_scanning_element(xmlTextReaderPtr reader, Tbflangparsing * bfparser, gin
 					}
 					name = xmlTextReaderName(reader);
 					if (xmlStrEqual(name, (xmlChar *) "context")) {
+						if (processed_context) {
+							g_print("Error in language file: element %s / %s has multiple inner contexts\n",id,pattern);
+						}
 						DBG_PARSING("in pattern, found countext\n");
 						nextcontext = process_scanning_context(reader, bfparser, contextstack);
 						match_set_nextcontext(bfparser->st, matchnum, nextcontext);
+						processed_context=TRUE;
 					} else if (xmlStrEqual(name, (xmlChar *) "reference")) {
 						DBG_PARSING("in pattern, found reference\n");
 						if (!xmlTextReaderIsEmptyElement(reader)) {
@@ -964,7 +995,7 @@ add_attribute_to_tag(Tbflangparsing * bfparser, const gchar *attrstring, gint co
 		gint16 startscontext;
 		gchar *tmp;
 		gchar **splitted = g_strsplit(attrstring, "=", -1);
-		
+
 		/*g_print("tag attribute contains a '=', lookup context %s\n",splitted[1]);*/
 		startscontext = GPOINTER_TO_INT(g_hash_table_lookup(bfparser->contexts, splitted[1]));
 		if (startscontext == 0) {
@@ -1409,12 +1440,20 @@ process_scanning_context(xmlTextReaderPtr reader, Tbflangparsing * bfparser, GQu
 #endif
 	depth = xmlTextReaderDepth(reader);
 	isempty = xmlTextReaderIsEmptyElement(reader);
-	
+
 	parse_attributes(bfparser->bflang,reader, attribs, bfparser->load_completion ? 7 : 6);
 	DBG_PARSING("found <context> with id=%s, idref=%s\n", id, idref);
 	if (idref && idref[0]) {
 		DBG_PARSING("lookup context %s in hash table..\n", idref);
 		context = GPOINTER_TO_INT(g_hash_table_lookup(bfparser->contexts, idref));
+		if (context == 0 && (!id || isempty)) {
+			g_print("Error in language file: context with id %s does not exist\n",idref);
+		}
+#ifdef DEVELOPMENT
+		if (context == 0) {
+			g_print("Context has idref=%s which does not exist, isempty=%d, id=%s\n",idref,isempty,id);
+		}
+#endif
 		g_free(idref);
 		if (context != 0 || (!id && !symbols && !highlight && !autocomplete_case_insens)) {
 			/* if the tag is not empty, we have to forward to the end of the tag now */
@@ -1487,6 +1526,27 @@ process_scanning_context(xmlTextReaderPtr reader, Tbflangparsing * bfparser, GQu
 	return context;
 }
 
+static void
+bftextview2_match_conditions(Tbflangparsing * bfparser) {
+	gint i;
+	GHashTable *ht;
+	g_print("bftextview2_match_conditions, have %d conditions\n",bfparser->st->conditions->len);
+	for (i = 1; i < bfparser->st->conditions->len; i++) {
+		g_print("bftextview2_match_conditions,running condition %d with refname %s\n",i,g_array_index(bfparser->st->conditions, Tpattern_condition, i).refname);
+		if (!g_array_index(bfparser->st->conditions, Tpattern_condition, i).refname) {
+			g_warning("Error in language file, condition refers to non existing id %s",g_array_index(bfparser->st->conditions, Tpattern_condition, i).refname);
+			continue;
+		}
+		if (g_array_index(bfparser->st->conditions, Tpattern_condition, i).relationtype == 1 || g_array_index(bfparser->st->conditions, Tpattern_condition, i).relationtype == 2) {
+			 ht = bfparser->contexts;
+		} else {
+			 ht = bfparser->patterns;
+		}
+		g_array_index(bfparser->st->conditions, Tpattern_condition, i).ref = GPOINTER_TO_INT(g_hash_table_lookup(ht, g_array_index(bfparser->st->conditions, Tpattern_condition, i).refname));
+		g_print("bftextview2_match_conditions, set ref %d for %s\n",g_array_index(bfparser->st->conditions, Tpattern_condition, i).ref, g_array_index(bfparser->st->conditions, Tpattern_condition, i).refname);
+	}
+}
+
 static gpointer
 build_lang_thread(gpointer data)
 {
@@ -1549,6 +1609,7 @@ build_lang_thread(gpointer data)
 				g_array_free(bfparser->st->contexts, TRUE);
 				g_array_free(bfparser->st->comments, TRUE);
 				g_array_free(bfparser->st->blocks, TRUE);
+				g_array_free(bfparser->st->conditions, TRUE);
 				g_slice_free(Tscantable, bfparser->st);
 				bfparser->st = NULL;
 				xmlFree(name);
@@ -1620,6 +1681,9 @@ build_lang_thread(gpointer data)
 	/* do some final memory management */
 	if (bfparser->st) {
 		gint i, tablenum=0, largest_table=0;
+
+		bftextview2_match_conditions(bfparser);
+
 		bfparser->st->contexts->data =
 			g_realloc(bfparser->st->contexts->data, (bfparser->st->contexts->len + 1) * sizeof(Tcontext));
 		bfparser->st->matches->data =
@@ -1628,6 +1692,8 @@ build_lang_thread(gpointer data)
 			g_realloc(bfparser->st->comments->data, (bfparser->st->comments->len + 1) * sizeof(Tcomment));
 		bfparser->st->blocks->data =
 			g_realloc(bfparser->st->blocks->data, (bfparser->st->blocks->len + 1) * sizeof(Tpattern_block));
+		bfparser->st->conditions->data =
+			g_realloc(bfparser->st->conditions->data, (bfparser->st->conditions->len + 1) * sizeof(Tpattern_condition));
 		/* now optimise the DFA tables for each context */
 		for (i = 1; i < bfparser->st->contexts->len; i++) {
 			g_array_index(bfparser->st->contexts, Tcontext, i).table->data = g_realloc(g_array_index(bfparser->st->contexts, Tcontext, i).table->data, (g_array_index(bfparser->st->contexts, Tcontext, i).table->len + 1) * sizeof(Ttablerow));
@@ -1843,6 +1909,7 @@ bflang_cleanup_scantable(Tbflang * bflang)
 	g_array_free(bflang->st->contexts, TRUE);
 	g_array_free(bflang->st->comments, TRUE);
 	g_array_free(bflang->st->blocks, TRUE);
+	g_array_free(bflang->st->conditions, TRUE);
 	g_slice_free(Tscantable, bflang->st);
 	bflang->st = NULL;
 }
