@@ -1,7 +1,7 @@
 /* Bluefish HTML Editor
  * bftextview2_patcompile.c
  *
- * Copyright (C) 2008,2009,2011,2013 Olivier Sessink
+ * Copyright (C) 2008,2009,2011,2013,2014 Olivier Sessink
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -636,6 +636,11 @@ compile_keyword_to_DFA(Tscantable * st, const gchar * keyword, guint16 matchnum,
 	g_queue_push_head(positions,
 					  GINT_TO_POINTER((gint) 0));
 
+	if (!keyword) {
+		g_warning("compile_keyword_to_DFA, called without keyword!\n");
+		return;
+	}
+
 	if (case_insens) {
 		/* make complete string lowercase */
 		pattern = g_ascii_strdown(keyword, -1);
@@ -851,7 +856,25 @@ compile_existing_match(Tscantable * st, guint16 matchnum, gint16 context)
 	}
 	match_autocomplete_reference(st, matchnum, context);
 }
+#ifdef CONDITIONALPATTERN
 
+void
+pattern_set_condition(Tscantable * st, guint16 matchnum, gchar *refname, gint relation, gint mode)
+{
+	guint16 condnum = st->conditions->len;
+	DBG_PARSING("pattern_set_condition, condnum=%d, called with refname %s for matchnum %d\n",condnum,refname,matchnum);
+	g_array_set_size(st->conditions, st->conditions->len + 1);
+	if (mode < 1 || mode > 4) {
+		g_warning("Error in language file: condition mode %d is not defined\n",mode);
+		return;
+	}
+	g_array_index(st->conditions, Tpattern_condition, condnum).refname = g_strdup(refname);
+	g_array_index(st->conditions, Tpattern_condition, condnum).parentrelation = relation;
+	g_array_index(st->conditions, Tpattern_condition, condnum).relationtype = mode;
+	DBG_PARSING("pattern %d (%s) now has condition %d\n",matchnum,g_array_index(st->matches, Tpattern, matchnum).pattern,condnum);
+	g_array_index(st->matches, Tpattern, matchnum).condition = condnum;
+}
+#endif /*CONDITIONALPATTERN*/
 void
 pattern_set_blockmatch(Tscantable * st, guint16 matchnum,
 							gboolean starts_block,
@@ -1071,9 +1094,11 @@ scantable_new(guint size_table, guint size_matches, guint size_contexts)
 	st->matches = g_array_sized_new(TRUE, TRUE, sizeof(Tpattern), size_matches);
 	st->comments = g_array_sized_new(TRUE, FALSE, sizeof(Tcomment), 8);
 	st->blocks = g_array_sized_new(TRUE, FALSE, sizeof(Tpattern_block), 8);
+	st->conditions = g_array_sized_new(TRUE, FALSE, sizeof(Tpattern_block), 8);
 	st->matches->len = 1;		/* match 0 means no match */
 	st->contexts->len = 1;		/* a match with nextcontext 0 means no context change, so we cannot use context 0 */
 	st->blocks->len = 1;			/* block 0 means no block */
+	st->conditions->len = 1;
 	return st;
 }
 
