@@ -128,49 +128,63 @@ extern void g_none(gchar * first, ...);
 /*************************************/
 /*** priorities for the main loop ****/
 /*************************************/
+/* #define DEBUG_SIGNALS */
+#ifdef DEBUG_SIGNALS
+#define DEBUG_SIG g_print
+#else
+#if defined(__GNUC__) || defined(__SUNPRO_C) && (__SUNPRO_C > 0x580)
+#define DEBUG_SIG(args...)
+ /**/
+#else							/* notdef __GNUC__ || __SUNPRO_C */
+extern void g_none(char * first, ...);
+#define DEBUG_SIG g_none
+#endif							/* __GNUC__ || __SUNPRO_C */
+#endif							/* DEBUG_SIGNALS */
 
 /*
 G_PRIORITY_HIGH -100 			Use this for high priority event sources. It is not used within GLib or GTK+.
-G_PRIORITY_DEFAULT 0 			Use this for default priority event sources. In GLib this priority is used when adding 
-										timeout functions with g_timeout_add(). 
-G_PRIORITY_HIGH_IDLE 100 		Use this for high priority idle functions. 
-G_PRIORITY_DEFAULT_IDLE 200 	Use this for default priority idle functions. In GLib this priority is used when adding idle 
+G_PRIORITY_DEFAULT 0 			Use this for default priority event sources. In GLib this priority is used when adding
+										timeout functions with g_timeout_add().
+G_PRIORITY_HIGH_IDLE 100 		Use this for high priority idle functions.
+G_PRIORITY_DEFAULT_IDLE 200 	Use this for default priority idle functions. In GLib this priority is used when adding idle
 										functions with g_idle_add().
 G_PRIORITY_LOW 300
 
 GDK  uses   0 for events from the X server.
-GTK+ uses 110 for resizing operations 
-GTK+ uses 120 for redrawing operations. (This is done to ensure 
-										that any pending resizes are processed before any pending 
+GTK+ uses 110 for resizing operations
+GTK+ uses 120 for redrawing operations. (This is done to ensure
+										that any pending resizes are processed before any pending
 										redraws, so that widgets are not redrawn twice unnecessarily.)
 */
 
-/* inserting data into a GtkTextBuffer should be in a lower priority than 
-the drawing of the GUI, otherwise the bluefish GUI won't show when loading 
-large files from the commandline. 
+/* inserting data into a GtkTextBuffer should be in a lower priority than
+the drawing of the GUI, otherwise the bluefish GUI won't show when loading
+large files from the commandline.
 I don't understand what it interacts with, but 145 is a too high priority
 so set it lower to 155 */
 #define FILEINTODOC_PRIORITY 155
 #define FILE2DOC_PRIORITY 155
-/* doc activate will stop scanning for the old document and schedule 
+/* doc activate will stop scanning for the old document and schedule
 for the new document. Set it between the X event (0) and the normal
 gtk events (100) */
 #define NOTEBOOKCHANGED_DOCACTIVATE_PRIORITY 50
 /* set between a X event (0) and a normal event (100) */
-#define SCANNING_IDLE_PRIORITY 10 
-/* set idle after timeout scanning to 115. 
-		a higher priority (109 is too high) makes bluefish go greyed-out 
+#define SCANNING_IDLE_PRIORITY 10
+/* set idle after timeout scanning to 115.
+		a higher priority (109 is too high) makes bluefish go greyed-out
 		(it will not redraw if required while the loop is running)
-	   and a much lower priority (199 is too low) will first draw 
+	   and a much lower priority (199 is too low) will first draw
 	   all textstyles on screen before the next burst of scanning is done */
-#define SCANNING_IDLE_AFTER_TIMEOUT_PRIORITY 115	
+#define SCANNING_IDLE_AFTER_TIMEOUT_PRIORITY 115
 /*  make sure that we don't scan or spellcheck a file that will be scanned again we do timeout
-scanning in a lower priority timeout than the language file notice 
+scanning in a lower priority timeout than the language file notice
 so a newly loaded language file uses a priority 113 event to notice all documents to be rescanned. */
 #define BUILD_LANG_FINISHED_PRIORITY 113
 
 #define BFLANGSCAN_FINISHED_PRIORITY 101
 
+#define BLUEFISH_STARTUP_IN_IDLE_PRIORITY (G_PRIORITY_DEFAULT_IDLE-50)
+
 /*********************/
 /* undo/redo structs */
 /*********************/
@@ -179,16 +193,17 @@ typedef enum {
 } undo_op_t;
 
 typedef struct {
-	GList *entries;				/* the list of entries that should be undone in one action */
+	gpointer next, prev; /* should equal BF_ELIST_HEAD as defined in bf_lib.h */
+	gpointer entries;				/* the list of entries that should be undone in one action */
 	gint32 changed;				/* doc changed status at this undo node */
 	guint32 action_id;
 } unregroup_t;
 
 typedef struct {
-	GList *first;
-	GList *last;
+	gpointer first;
+	gpointer last;
 	unregroup_t *current;
-	GList *redofirst;
+	gpointer redofirst;
 	gint num_groups;
 } unre_t;
 
@@ -231,6 +246,9 @@ typedef struct {
 	gpointer load;				/* during load */
 	gint goto_line;
 	gint goto_offset;
+	gboolean align_center; /* how to align textview after offseting it */
+	gint cursor_offset; /* cursor position in textview */
+	gboolean load_first; /*sets priority of async loading */
 	gushort close_doc;
 	gushort close_window;
 
@@ -267,13 +285,13 @@ typedef struct {
 	gint editor_tab_indent_sel; /* tab key will indent a selected block */
 	gint editor_auto_close_brackets;
 	gint use_system_tab_font;
+	gint max_shown_filename_len; /* the maximum length for the filename shown in the tab */
 	gchar *tab_font_string;		/* notebook tabs font */
 	/*  gchar *tab_color_normal; *//* notebook tabs text color normal.  This is just NULL! */
 	gchar *tab_color_modified;	/* tab text color when doc is modified and unsaved */
 	gchar *tab_color_loading;	/* tab text color when doc is loading */
 	gchar *tab_color_error;		/* tab text color when doc has errors */
 	gint visible_ws_mode;
-	gint right_margin_pos;
 	/* new replacements: */
 	GList *external_command;	/* array: name,command,is_default_browser */
 	GList *external_filter;		/* array: name,command */
@@ -289,6 +307,7 @@ typedef struct {
 	gint max_recent_files;		/* length of Open Recent list */
 	gint max_dir_history;		/* length of directory history */
 	gint backup_file;			/* wheather to use a backup file */
+	gint show_long_line_warning;
 	/* GIO has hardcoded backup file names */
 /*	gchar *backup_suffix;  / * the string to append to the backup filename */
 /*	gchar *backup_prefix;  / * the string to prepend to the backup filename (between the directory and the filename) */
@@ -320,10 +339,11 @@ typedef struct {
 	gint open_in_running_bluefish;	/* open commandline documents in already running process */
 	gint open_in_new_window;	/* open commandline files in a new window as opposed to an existing window */
 	gint register_recent_mode; /* 0=none,1=all,2=project only*/
+	gint recent_means_recently_closed;
 	GList *plugin_config;		/* array, 0=filename, 1=enabled, 2=name */
 	gint use_system_colors;
 	gchar *btv_color_str[BTV_COLOR_COUNT];	/* editor colors */
-	GList *textstyles;			/* tet styles: name,foreground,background,weight,style */
+	GList *textstyles;			/* text styles: name,foreground,background,weight,style */
 	gint block_folding_mode;
 	GList *highlight_styles;
 	GList *bflang_options;		/* array with: lang_name, option_name, value */
@@ -334,6 +354,7 @@ typedef struct {
 	gboolean delay_full_scan;
 	gint delay_scan_time;
 	gint autocomp_popup_mode;	/* delayed or immediately */
+	gint autocomp_min_prefix_len; /* minimum number of matching characters before autocomp is activated */
 	gboolean reduced_scan_triggers;
 	gint autosave;
 	gint autosave_time;
@@ -342,11 +363,15 @@ typedef struct {
 	gchar *autosave_file_suffix;
 	gchar *language;
 	gint rcfile_from_old_version;
-	gint adv_textview_right_margin; /* advanced option for the textview margin */
-	gint adv_textview_left_margin; /* advanced option for the textview margin */
+	gint right_margin_pos;
+	gint adv_textview_right_margin; /* advanced option for the amount of whitespace inside the textview widget */
+	gboolean wrap_on_right_margin; /* sets adv_textview_right_margin dynamically based on right_margin_pos */
+	gint adv_textview_left_margin; /* advanced option for the amount of whitespace inside the textview widget */
+	gint adv_smart_indent_mode; /* advanced option for advanced indent mode, normal=1, but if set to 2 the editor 
+											will outdent if the previous character was a closing bracket */
 } Tproperties;
 
-/* the Tglobalsession contains all settings that can change 
+/* the Tglobalsession contains all settings that can change
 over every time you run Bluefish, so things that *need* to be
 saved after every run! */
 typedef struct {
@@ -365,6 +390,7 @@ typedef struct {
 	GList *reference_files;		/* all reference files */
 	GList *recent_projects;
 	GList *encodings;			/* all encodings you can choose from, array with 0=human name, 1=name, 2="0" or "1" if it should be user visible or not */
+	GList *custombflangmime; /* bflang name - mime type name */
 #ifdef WITH_MSG_QUEUE
 	gint msg_queue_poll_time;	/* milliseconds, automatically tuned to your system */
 #endif
@@ -427,7 +453,7 @@ typedef struct {
 	gint spell_insert_entities;
 	gchar *spell_lang;
 #endif
-	/* if you add strings or lists to the session, please make sure they are free'ed 
+	/* if you add strings or lists to the session, please make sure they are free'ed
 	in free_session() in project.c */
 	gchar *ssearch_text;
 	gchar *default_mime_type;
@@ -541,7 +567,7 @@ typedef struct {
 #ifdef HAVE_LIBENCHANT
 	gpointer *ed;				/* EnchantDict */
 #endif
-	/* following is a new approach, that we have only a gpointer here, whioh is typecasted 
+	/* following is a new approach, that we have only a gpointer here, whioh is typecasted
 	   in the file where it is needed */
 	gpointer outputbox;
 	gpointer bfspell;
@@ -572,12 +598,13 @@ typedef struct {
 	guint autosave_id;			/* used with g_timeout_add */
 	guint periodic_check_id;	/* used with g_timeout_add */
 	GList *bfwinlist;
+	GHashTable *alldochash;			/* hash table with uri as key and Tdocument as value */
 	Tsessionvars *session;		/* holds all session variables for non-project windows */
 	gpointer fb2config;			/* filebrowser2config */
 	GList *filefilters;			/* initialized by fb2config functions */
 	GList *templates; 			/* loaded in rcfile.c */
 	Tdocument *bevent_doc;
-	gint bevent_charoffset; 	/* for example used in the spellcheck code to find on which 
+	gint bevent_charoffset; 	/* for example used in the spellcheck code to find on which
 											word the user clicked */
 	guint autocomp_accel_key;				 /* by default <ctrl><space> activates autocompletion */
 	GdkModifierType autocomp_accel_mods; /* but this shortcut is also used to switch input languages for example by chinese users */
@@ -596,6 +623,9 @@ typedef struct {
 									   is destroyed */
 	GSList *pref_initgui; /* register a PrefInitguiCallback function here to add a preferences panel */
 	GSList *pref_apply; /* PrefApplyCallback */
+#ifdef MAC_INTEGRATION
+	gint osx_status; /* 0- normal operation, 1- osx app is terminating, 2-osx app is suspended (only app menu visible). */
+#endif
 } Tmain;
 
 extern EXPORT Tmain *main_v;
@@ -640,7 +670,7 @@ void bluefish_exit_request(void);
 #define GDK_KEY_7 GDK_7
 #define GDK_KEY_8 GDK_8
 #define GDK_KEY_9 GDK_9
-#define GDK_KEY_F1 GDK_F1 
+#define GDK_KEY_F1 GDK_F1
 #define GDK_KEY_F12 GDK_F12
 #define GDK_KEY_Delete GDK_Delete
 #define GDK_KEY_BackSpace GDK_BackSpace
@@ -653,11 +683,22 @@ void bluefish_exit_request(void);
 /*#define GDK_KEY_ GDK_*/
 #define GTK_COMBO_BOX_TEXT(arg) GTK_COMBO_BOX(arg)
 #define gtk_combo_box_text_get_active_text gtk_combo_box_get_active_text
-#define gtk_combo_box_text_new_with_entry gtk_combo_box_entry_new_text 
+#define gtk_combo_box_text_new_with_entry gtk_combo_box_entry_new_text
 #define gtk_combo_box_text_new gtk_combo_box_new_text
 #define gtk_combo_box_text_append_text gtk_combo_box_append_text
 #define gtk_combo_box_text_prepend_text gtk_combo_box_prepend_text
 #define gtk_combo_box_text_remove gtk_combo_box_remove_text
 #endif /* GTK_CHECK_VERSION(2,24,0) */
 
+#ifdef OLD_MAC_INTEGRATION
+#define GtkosxApplication GtkOSXApplication
+#define gtkosx_application_ready gtk_osxapplication_ready
+#define GTKOSX_TYPE_APPLICATION GTK_TYPE_OSX_APPLICATION
+#define gtkosx_application_sync_menubar gtk_osxapplication_sync_menubar
+#define gtkosx_application_get_resource_path quartz_application_get_resource_path
+#define gtkosx_application_set_window_menu gtk_osxapplication_set_window_menu
+#define gtkosx_application_insert_app_menu_item gtk_osxapplication_insert_app_menu_item
+#define gtkosx_application_set_menu_bar gtk_osxapplication_set_menu_bar
+#define gtkosx_application_get_bundle_id quartz_application_get_bundle_id
+#endif
 #endif							/* __BLUEFISH_H_ */
