@@ -1,7 +1,7 @@
 /* Bluefish HTML Editor
  * file.c - file operations based on GIO
  *
- * Copyright (C) 2002-2012 Olivier Sessink
+ * Copyright (C) 2002-2014 Olivier Sessink
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -76,6 +76,7 @@ static Tasyncqueue ffdqueue;
 void
 file_static_queues_init(void)
 {
+	DEBUG_MSG("file_static_queues_init, started\n");
 	queue_init(&ofqueue, 8, openfile_run);
 	queue_init(&ffdqueue, 8, findfiles_rundir);
 	queue_init(&fiqueue, 8, fill_fileinfo_run);
@@ -555,7 +556,7 @@ openfile_async_lcb(GObject * source_object, GAsyncResult * res, gpointer user_da
 	gchar *buffer = NULL;
 	gchar *etag = NULL;
 	gsize size = 0;
-
+	DEBUG_MSG("openfile_async_lcb, of=%p with uri=%p\n",of,of->uri);
 	g_file_load_contents_finish(of->uri, res, &buffer, &size, &etag, &error);
 	if (error) {
 		DEBUG_MSG("openfile_async_lcb, finished, received error code %d: %s\n", error->code, error->message);
@@ -571,8 +572,9 @@ openfile_async_lcb(GObject * source_object, GAsyncResult * res, gpointer user_da
 				queue_worker_ready(&ofqueue);
 			}
 		} else {
-			g_warning("while opening file, received error %d: %s\n", error->code, error->message);
+			g_warning("while opening file %s, received error %d: %s\n", g_file_get_path(of->uri), error->code, error->message);
 			of->callback_func(OPENFILE_ERROR, error, NULL, 0, of->callback_data);
+			openfile_cleanup(of);
 			g_free(buffer);
 		}
 		g_error_free(error);
@@ -590,6 +592,7 @@ static void
 openfile_run(gpointer data)
 {
 	Topenfile *of = data;
+	DEBUG_MSG("openfile_run, start async load for of=%p with uri=%p\n",of,of->uri);
 	g_file_load_contents_async(of->uri, of->cancel, openfile_async_lcb, of);
 }
 
@@ -599,6 +602,7 @@ file_openfile_uri_async(GFile * uri, Tbfwin * bfwin, OpenfileAsyncCallback callb
 {
 	Topenfile *of;
 	of = g_slice_new(Topenfile);
+	DEBUG_MSG("file_openfile_uri_async, of=%p, called for uri=%p\n",of,uri);
 	of->callback_data = callback_data;
 	of->callback_func = callback_func;
 	of->uri = uri;
@@ -634,9 +638,11 @@ fileintodoc_finished_idle_lcb(gpointer data)
 	DEBUG_SIG("file2doc_finished_idle_lcb, started, priority %d\n",FILEINTODOC_PRIORITY);
 	DEBUG_MSG("fileintodoc_finished_idle_lcb, loading the data for doc %p\n",fid->doc);
 	if (fid->isTemplate || fid->untiledRecovery) {
-		doc_buffer_to_textbox(fid->doc, fid->buffer->data, fid->buflen, FALSE, TRUE);
-		/*          DEBUG_MSG("fileintodoc_lcb, fid->doc->hl=%p, %s, first=%p\n",fid->doc->hl,fid->doc->hl->type,((GList *)g_list_first(main_v->filetypelist))->data); */
-		doc_reset_filetype(fid->doc, fid->doc->uri, fid->buffer->data, fid->buflen);
+		if (fid->buffer) {
+			doc_buffer_to_textbox(fid->doc, fid->buffer->data, fid->buflen, FALSE, TRUE);
+			/*          DEBUG_MSG("fileintodoc_lcb, fid->doc->hl=%p, %s, first=%p\n",fid->doc->hl,fid->doc->hl->type,((GList *)g_list_first(main_v->filetypelist))->data); */
+			doc_reset_filetype(fid->doc, fid->doc->uri, fid->buffer->data, fid->buflen);
+		}
 		doc_set_tooltip(fid->doc);
 		doc_set_status(fid->doc, DOC_STATUS_COMPLETE);
 		bfwin_docs_not_complete(fid->doc->bfwin, FALSE);
@@ -666,7 +672,9 @@ fileintodoc_finished_idle_lcb(gpointer data)
 	if (fid->bfwin->current_document == fid->doc) {
 		doc_force_activate(fid->doc);
 	}
-	refcpointer_unref(fid->buffer);
+	if (fid->buffer) {
+		refcpointer_unref(fid->buffer);
+	}
 	fileintodoc_cleanup(data);
 	return FALSE;
 }
@@ -675,6 +683,7 @@ static void
 fileintodoc_lcb(Topenfile_status status, GError * gerror, Trefcpointer * buffer, goffset buflen, gpointer data)
 {
 	Tfileintodoc *fid = data;
+	DEBUG_MSG("fileintodoc_lcb, fid=%p,status=%d\n",fid,status);
 	switch (status) {
 	case OPENFILE_FINISHED:
 		/* a GtkTextView with lots of data displays incredibly slow. So during
@@ -710,8 +719,13 @@ fileintodoc_lcb(Topenfile_status status, GError * gerror, Trefcpointer * buffer,
 	case OPENFILE_ERROR_NOCHANNEL:
 	case OPENFILE_ERROR_NOREAD:
 		/* TODO: use gerror information to notify the user, for example in the statusbar */
-		DEBUG_MSG("fileitodoc_lcb, ERROR status=%d, cleanup!!!!!\n", status);
+		DEBUG_MSG("fileitodoc_lcb, ERROR for %s status=%d, cleanup!!!!!\n", g_file_get_uri(fid->uri), status);
+		if (fid->isTemplate) {
+			g_idle_add_full(FILEINTODOC_PRIORITY,fileintodoc_finished_idle_lcb,fid,NULL);
+			break;
+		}
 		fid->doc->load = NULL;
+		bfwin_docs_not_complete(fid->doc->bfwin, FALSE);
 		fileintodoc_cleanup(data);
 		break;
 	}
@@ -723,6 +737,7 @@ file_into_doc(Tdocument * doc, GFile * uri, gboolean isTemplate, gboolean untile
 {
 	Tfileintodoc *fid;
 	fid = g_slice_new(Tfileintodoc);
+	DEBUG_MSG("file_into_doc, fid=%p, called for doc=%p, uri=%p,isTemplate=%d,untiledRecovery=%d\n",fid,doc,uri,isTemplate,untiledRecovery);
 	fid->bfwin = doc->bfwin;
 	fid->doc = doc;
 	fid->isTemplate = isTemplate;
@@ -739,6 +754,7 @@ file_into_doc(Tdocument * doc, GFile * uri, gboolean isTemplate, gboolean untile
 /************ MAKE DOCUMENT FROM ASYNC OPENED FILE ************************/
 typedef struct {
 	Topenfile *of;
+	guint idle_cb_id;
 	Tbfwin *bfwin;
 	Tdocument *doc;
 	GFile *uri;
@@ -754,6 +770,7 @@ file2doc_cleanup(Tfile2doc * f2d)
 {
 	DEBUG_MSG("file2doc_cleanup, %p, num open documents=%d\n", f2d, g_list_length(f2d->bfwin->documentlist));
 	g_object_unref(f2d->uri);
+	f2d->doc->load = NULL;
 	if (f2d->recover_uri)
 		g_object_unref(f2d->recover_uri);
 	g_slice_free(Tfile2doc, f2d);
@@ -763,8 +780,14 @@ void
 file2doc_cancel(gpointer f2d)
 {
 	DEBUG_MSG("file2doc_cancel, called for %p\n", f2d);
-	openfile_cancel(((Tfile2doc *) f2d)->of);
-	/* no cleanup, there is a CANCELLED callback coming */
+	if (((Tfile2doc *) f2d)->idle_cb_id) {
+		g_source_remove(((Tfile2doc *) f2d)->idle_cb_id);
+		((Tfile2doc *) f2d)->idle_cb_id = 0;
+		file2doc_cleanup(((Tfile2doc *) f2d));
+	} else {
+		openfile_cancel(((Tfile2doc *) f2d)->of);
+		/* no cleanup, there is a CANCELLED callback coming */
+	}
 }
 
 static gboolean
@@ -801,6 +824,7 @@ static gboolean
 file2doc_finished_idle_lcb(gpointer data)
 {
 	Tfile2doc * f2d=data;
+	gboolean conversion_status;
 	Trefcpointer *refp = f2d->buffer;
 	DEBUG_SIG("file2doc_finished_idle_lcb, started, priority %d\n",FILE2DOC_PRIORITY);
 	DEBUG_MSG("file2doc_finished_idle_lcb started for doc %p\n",f2d->doc);
@@ -808,8 +832,11 @@ file2doc_finished_idle_lcb(gpointer data)
 		GtkTextIter itstart, itend;
 
 		f2d->recovery_status = 2;
-		doc_buffer_to_textbox(f2d->doc, f2d->buffer->data, f2d->buflen, FALSE, TRUE);
-		g_print("file2doc_finished_idle_lcb, recovery of existing file, inserted original file\n");
+		conversion_status = doc_buffer_to_textbox(f2d->doc, f2d->buffer->data, f2d->buflen, FALSE, TRUE);
+		if(!conversion_status) {
+			doc_set_readonly(f2d->doc, TRUE);
+		}
+		DEBUG_MSG("file2doc_finished_idle_lcb, recovery of existing file, inserted original file\n");
 		f2d->doc->block_undo_reg = TRUE;
 		doc_unre_new_group(f2d->doc);
 		doc_unre_add(f2d->doc, f2d->buffer->data, 0, g_utf8_strlen(f2d->buffer->data, f2d->buflen), UndoDelete);
@@ -818,7 +845,10 @@ file2doc_finished_idle_lcb(gpointer data)
 		DEBUG_MSG("file2doc_finished_idle_lcb, recovery of existing file, deleted contents, load autosaved file\n");
 		f2d->of = file_openfile_uri_async(f2d->recover_uri, f2d->bfwin, file2doc_lcb, f2d);
 	} else if (f2d->recovery_status == 2) {
-		doc_buffer_to_textbox(f2d->doc, f2d->buffer->data, f2d->buflen, FALSE, TRUE);
+		conversion_status = doc_buffer_to_textbox(f2d->doc, f2d->buffer->data, f2d->buflen, FALSE, TRUE);
+		if(!conversion_status) {
+			doc_set_readonly(f2d->doc, TRUE);
+		}
 		doc_unre_add(f2d->doc, f2d->buffer->data, 0, g_utf8_strlen(f2d->buffer->data, f2d->buflen), UndoInsert);
 		f2d->doc->block_undo_reg = FALSE;
 		doc_unre_new_group(f2d->doc);
@@ -834,7 +864,10 @@ file2doc_finished_idle_lcb(gpointer data)
 		f2d->doc->load = NULL;
 		file2doc_cleanup(data);
 	} else {
-		doc_buffer_to_textbox(f2d->doc, f2d->buffer->data, f2d->buflen, FALSE, TRUE);
+		conversion_status = doc_buffer_to_textbox(f2d->doc, f2d->buffer->data, f2d->buflen, FALSE, TRUE);
+		if(!conversion_status) {
+			doc_set_readonly(f2d->doc, TRUE);
+		}
 		doc_reset_filetype(f2d->doc, f2d->doc->uri, f2d->buffer->data, f2d->buflen);
 		doc_set_tooltip(f2d->doc);
 		doc_set_status(f2d->doc, DOC_STATUS_COMPLETE);
@@ -869,9 +902,9 @@ file2doc_finished_idle_lcb(gpointer data)
 		DEBUG_MSG("file2doc_finished_idle_lcb, goto_line=%d, goto_offset=%d, cursor_offset=%d\n", f2d->doc->goto_line,  f2d->doc->goto_offset,  f2d->doc->cursor_offset);
 		if (f2d->doc->goto_line > 0 || f2d->doc->goto_offset > 0 || f2d->doc->cursor_offset > 0) {
 			if (f2d->doc->load_first) {
-				g_idle_add_full(FILE2DOC_PRIORITY-2,file2doc_goto_idle_cb, f2d, NULL);
+				f2d->idle_cb_id = g_idle_add_full(FILE2DOC_PRIORITY-2,file2doc_goto_idle_cb, f2d, NULL);
 			} else {
-				g_idle_add_full(FILE2DOC_PRIORITY-1,file2doc_goto_idle_cb, f2d, NULL);
+				f2d->idle_cb_id = g_idle_add_full(FILE2DOC_PRIORITY-1,file2doc_goto_idle_cb, f2d, NULL);
 			}
 		} else {
 			f2d->doc->goto_line = -1;
@@ -899,9 +932,9 @@ file2doc_lcb(Topenfile_status status, GError * gerror, Trefcpointer * buffer, go
 		f2d->buflen = buflen;
 		refcpointer_ref(buffer);
 		if (f2d->doc->load_first) {
-			g_idle_add_full(FILE2DOC_PRIORITY-1, file2doc_finished_idle_lcb, f2d, NULL);
+			f2d->idle_cb_id = g_idle_add_full(FILE2DOC_PRIORITY-1, file2doc_finished_idle_lcb, f2d, NULL);
 		} else {
-			g_idle_add_full(FILE2DOC_PRIORITY, file2doc_finished_idle_lcb, f2d, NULL);
+			f2d->idle_cb_id = g_idle_add_full(FILE2DOC_PRIORITY, file2doc_finished_idle_lcb, f2d, NULL);
 		}
 		break;
 	case OPENFILE_CHANNEL_OPENED:
@@ -2103,7 +2136,7 @@ sync_directory(GFile * basedir, GFile * targetdir, gboolean delete_deprecated, g
 /* code to handle a file from the commandline, the filebrowser or from the message queue */
 
 void
-file_handle(GFile * uri, Tbfwin * bfwin, gchar * mimetype, gboolean external_input)
+file_handle(GFile * uri, Tbfwin * bfwin, gchar * mimetype, gboolean explicit_open)
 {
 	GFileInfo *finfo;
 	GError *error = NULL;
@@ -2133,7 +2166,7 @@ file_handle(GFile * uri, Tbfwin * bfwin, gchar * mimetype, gboolean external_inp
 	DEBUG_MSG("file_handle, got mime type %s\n", mime);
 	if (mime && strcmp(mime, "application/x-bluefish-project") == 0) {
 		project_open_from_file(bfwin, uri);
-	} else if (mime && strncmp(mime, "image", 5) == 0 && !external_input) {
+	} else if (mime && strncmp(mime, "image", 5) == 0 && !explicit_open) {
 		/* TODO: do something with the image, fire the image dialog? insert a tag? */
 		if (bfwin && bfwin->current_document) {
 			gchar *curi = NULL, *tmp;
