@@ -145,22 +145,27 @@ static UriRecord *get_nth_record(FileTreemodel * ftm, UriRecord * precord, gint
 static gchar *get_toplevel_name_for_uri(gchar * curi)
 {
 	gchar *needle;
+	const gchar *slash = "/";
 	if (!curi)
 		return NULL;
 
 	if (curi[0] == '/')
-		return g_strdup("/");
+		return g_strdup(slash);
 
 	if (strncmp(curi, "file:///", 8) == 0)
-		return g_strdup("/");
+		return g_strdup(slash);
 
 	needle = strstr(curi, "://");
 	DEBUG_MSG("searching for toplevel, got non-local uri %s\n", needle);
-	if (!needle) {
+	if (!needle || *(needle+3) == '\0') {
 		g_warning("cannot handle uri %s\n", curi);
 		return NULL;
 	}
 	needle = strchr(needle + 3, '/');
+	if (needle == NULL) {
+		/* we have a string like sftp://server.com */
+		return g_strconcat(curi, slash, NULL);
+	}
 	return g_strndup(curi, needle - curi + 1);
 }
 
@@ -1084,7 +1089,7 @@ UriRecord *filetreemodel_build_dir(FileTreemodel * ftm, GFile * uri, GtkTreeIter
 			name = get_toplevel_name(tmp);
 			/* there was no parent for this filesystem yet */
 			DEBUG_MSG("filetreemodel_build_dir, adding parent %s as fake folder\n", name);
-			record = add_single_uri(ftm, NULL, tmp, name, DIR_MIME_TYPE, "folder", TRUE, PANGO_WEIGHT_NORMAL);
+			record = add_single_uri(ftm, NULL, tmp, name?name:"?", DIR_MIME_TYPE, "folder", TRUE, PANGO_WEIGHT_NORMAL);
 			g_free(name);
 			break;
 		} else {
@@ -1260,7 +1265,11 @@ filetreemodel_get_value(GtkTreeModel * tree_model, GtkTreeIter * iter, gint colu
 		if (record->icon_name) {
 			g_value_set_string(value, record->icon_name);
 		} else {
+#ifndef MAC_INTEGRATION
 			g_value_set_string(value, "gtk-file");
+#else
+			g_value_set_string(value, "text-x-generic");
+#endif
 		}
 		break;
 	case filetreemodel_COL_WEIGHT:
