@@ -17,7 +17,7 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * use G_DEBUG=fatal-warnings 
+ * use G_DEBUG=fatal-warnings
  * gdb src/bluefish
  * to get backtraces what causes a warning
  */
@@ -352,7 +352,7 @@ add_uri_to_recent_dirs(Tfilebrowser2 * fb2, GFile * uri)
 	gchar *tmp;
 
 	tmp = g_file_get_uri(uri);
-
+	DEBUG_MSG("add_uri_to_recent_dirs, add %s to history stringlist\n",tmp);
 	fb2->bfwin->session->recent_dirs =
 		add_to_history_stringlist(fb2->bfwin->session->recent_dirs, tmp, TRUE);
 	g_free(tmp);
@@ -428,11 +428,11 @@ gboolean delayed_refresh_cb(gpointer data)
 	}
 	FB2CONFIG(main_v->fb2config)->uri_to_refresh = NULL;
 	FB2CONFIG(main_v->fb2config)->delayed_refresh_id = 0;
-	return FALSE;	
+	return FALSE;
 }
 
-/* 
-by delaying the refresh, if quickly change multiple tabs, you won't call a directory refresh for every document, only 
+/*
+by delaying the refresh, if quickly change multiple tabs, you won't call a directory refresh for every document, only
 a dir for a document where you stay more than 200ms will be refreshed
 */
 static void
@@ -451,7 +451,7 @@ register_delayed_refresh(GFile *uri) {
 		DEBUG_MSG("register_delayed_refresh, uri=%s is already in refresh, returning\n",g_file_get_path(uri));
 		return;
 	}
-	
+
 	if (FB2CONFIG(main_v->fb2config)->uri_to_refresh && g_file_equal(FB2CONFIG(main_v->fb2config)->uri_to_refresh,uri)) {
 		return;
 	}
@@ -611,7 +611,7 @@ fb2_refilter(Tfilebrowser2 * fb2)
 /*  END OF FILTERING FUNCTIONS, START OF DATA MODEL FUNCTIONS */
 /*****************************************************************************************************************************/
 
-void 
+void
 fb2_file_is_opened(GFile *uri, const gchar *mimetype)
 {
 	GtkTreeIter iter;
@@ -1053,7 +1053,7 @@ popup_menu_open(GtkAction * action, gpointer user_data)
 	uri = fb2_uri_from_file_selection(fb2, &mime);
 	if (uri) {
 		DEBUG_MSG("calling file_handle for popup menu\n");
-		file_handle(uri, fb2->bfwin, mime, FALSE);
+		file_handle(uri, fb2->bfwin, mime, TRUE);
 	}
 }
 
@@ -1843,6 +1843,8 @@ set_dir_v_root(Tfilebrowser2 *fb2, GFile *dir_uri)
 
 	if (dir_uri) {
 		/* treepath_for_uri returns a GtkTreePath for the uri, and builds it (using fb2_build_dir()) if needed */
+		if (fb2->filebrowser_viewmode != viewmode_flat)
+			filetreemodel_refresh_uri_async(FB2CONFIG(main_v->fb2config)->ftm, dir_uri);
 		basepath = treepath_for_uri(fb2, dir_uri);
 		DEBUG_MSG("fb2_set_dir_v_root, refilter, basepath=%p\n", basepath);
 		if (basepath) {
@@ -1853,7 +1855,7 @@ set_dir_v_root(Tfilebrowser2 *fb2, GFile *dir_uri)
 		refilter_dirlist(fb2, NULL);
 	}
 	if (fb2->dirselection_changed_id)
-		g_signal_handler_unblock(dirselection, fb2->dirselection_changed_id);	
+		g_signal_handler_unblock(dirselection, fb2->dirselection_changed_id);
 }
 
 
@@ -2003,6 +2005,14 @@ file_v_button_press_lcb(GtkWidget * widget, GdkEventButton * event, Tfilebrowser
 	return FALSE;				/* pass the event on */
 }
 
+static void
+add_parent_uri_to_recent_dirs(Tfilebrowser2 * fb2, GFile *uri)
+{
+	GFile *dir_uri = g_file_get_parent(uri);
+	add_uri_to_recent_dirs(fb2, dir_uri);
+	g_object_unref(dir_uri);
+}
+
 static void
 dir_v_row_activated_lcb(GtkTreeView * tree, GtkTreePath * path,
 						GtkTreeViewColumn * column, Tfilebrowser2 * fb2)
@@ -2020,7 +2030,9 @@ dir_v_row_activated_lcb(GtkTreeView * tree, GtkTreePath * path,
 	if (!record->isdir) {
 		DEBUG_MSG("calling file_handle for row_activated\n");
 		file_handle(record->uri, fb2->bfwin, record->fast_content_type, FALSE);
+		add_parent_uri_to_recent_dirs(fb2, record->uri);
 	} else { /* a directory */
+		add_uri_to_recent_dirs(fb2, record->uri);
 		if (fb2->filebrowser_viewmode == viewmode_flat) {
 			set_basedir_backend(fb2, record->uri);
 			filetreemodel_refresh_uri_async(FB2CONFIG(main_v->fb2config)->ftm, record->uri);
@@ -2046,8 +2058,8 @@ file_v_row_activated_lcb(GtkTreeView * tree, GtkTreePath * path,
 		gtk_tree_model_get(fb2->file_filter, &iter, filetreemodel_COL_RECORD, &record, -1);
 		DEBUG_MSG("calling file_handle for file_v row activat\n");
 		file_handle(record->uri, fb2->bfwin, record->fast_content_type, FALSE);
+		add_parent_uri_to_recent_dirs(fb2, record->uri);
 	}
-
 }
 
 static void
@@ -2313,7 +2325,7 @@ fb2_set_viewmode_widgets(Tfilebrowser2 * fb2, gint viewmode)
 		{"STRING", 0, TARGET_STRING},
 	};
 
-	
+
 	if (fb2->filebrowser_viewmode == viewmode) {
 		/* the current viewmode is the same as the requested viewmode
 		   we can return if all the widgets exist */
@@ -2335,7 +2347,7 @@ fb2_set_viewmode_widgets(Tfilebrowser2 * fb2, gint viewmode)
 		}
 		fb2->dir_v = fb2->file_v = NULL;
 		fb2->dir_filter = fb2->file_filter = NULL;
-		DEBUG_MSG("\n");
+		DEBUG_MSG("fb2_set_viewmode_widgets, reset dir_filter and file_filter\n");
 	}
 	fb2->filebrowser_viewmode = viewmode;
 
@@ -2496,8 +2508,18 @@ fb2_update_settings_from_session(Tbfwin * bfwin, Tdocument *active_doc)
 		DEBUG_MSG("fb2_update_settings_from_session, set basedir %s\n", tmp);
 		if (tmp && tmp[0]) {
 			GtkTreePath *fs_path, *filter_path;
-			GFile *uri = g_file_new_for_uri(strip_trailing_slash((gchar *) tmp));
+			GFile *uri = g_file_new_for_uri(strcmp(tmp,"file:///")==0?tmp:strip_trailing_slash((gchar *) tmp));
 			DEBUG_MSG("fb2_update_settings_from_session, set basedir %p\n",uri);
+			/* Check if basedir exists here since non-existing basedir will cause issues
+
+			TODO: this code slows down the main window if you load files from a remote
+			server over a slow connection because this code runs synchronous (so it will block the GUI).
+			we should do this somehow in the	asynchronous callbacks */
+			if (!g_file_query_exists(uri,NULL)) {
+				g_warning("fb2_update_settings_from_session, basedir %s does not exists, setting basedir to $HOME", g_file_get_path(uri));
+				g_object_unref(uri);
+				uri = g_file_new_for_path(g_get_home_dir()); /*If  basedir is not valid default to home directory */
+			}
 			fb2_set_basedir(fb2, uri);
 			fb2_set_dirmenu(fb2, uri, FALSE);
 			if (fb2->filebrowser_viewmode == viewmode_dual) {
@@ -2515,7 +2537,7 @@ fb2_update_settings_from_session(Tbfwin * bfwin, Tdocument *active_doc)
 					}
 					gtk_tree_path_free(fs_path);
 				}
-				
+
 			}
 			g_object_unref(uri);
 		}
@@ -2531,7 +2553,7 @@ fb2_update_settings_from_session(Tbfwin * bfwin, Tdocument *active_doc)
 		}
 		fb2config_set_documentroot_icon(uri);
 		g_object_unref(uri);
-	} 
+	}
 	/* TODO: set_basedir_backend already calls refilter in most cases (not if the
 	   requested basedir was already the active basedir), so
 	   we can optimise this and call refilter only when really needed. */
@@ -2599,7 +2621,7 @@ fb2_cleanup(Tbfwin * bfwin)
 		Tfilebrowser2 *fb2 = FILEBROWSER2(bfwin->fb2);
 		GList *actions, *list;
 		DEBUG_MSG("fb2_cleanup, fb2=%p, fb2->bfwin=%p, fb2->vbox=%p\n",fb2,fb2->bfwin,fb2->vbox);
-		
+
 		filetreemodel_dirchange_unregister_by_data(FB2CONFIG(main_v->fb2config)->ftm, fb2);
 		if (fb2->vbox) {
 			DEBUG_MSG("fb2_cleanup, we still have a vbox, destroy vbox\n");
