@@ -201,10 +201,10 @@ image_insert_dialogok_lcb(GtkWidget * widget, Timage_diag * imdg)
 			insert_integer_if_spin(imdg->dg->spin[1], cap("HEIGHT"), thestring,
 								   gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(imdg->dg->check[1])), 0);
 		if (!main_v->props.xhtml) {
-			thestring = insert_integer_if_spin(imdg->dg->spin[2], cap("BORDER"), thestring, FALSE, 1);
+			thestring = insert_if_spin(imdg->dg->spin[2], cap("BORDER"), thestring, FALSE);
 		}
-		thestring = insert_integer_if_spin(imdg->dg->spin[3], cap("HSPACE"), thestring, FALSE, 0);
-		thestring = insert_integer_if_spin(imdg->dg->spin[4], cap("VSPACE"), thestring, FALSE, 0);
+		thestring = insert_if_spin(imdg->dg->spin[3], cap("HSPACE"), thestring, FALSE);
+		thestring = insert_if_spin(imdg->dg->spin[4], cap("VSPACE"), thestring, FALSE);
 		thestring = insert_string_if_entry(GTK_ENTRY(imdg->dg->entry[1]), cap("NAME"), thestring, NULL);
 		thestring = insert_string_if_entry(GTK_ENTRY(imdg->dg->entry[2]), cap("ALT"), thestring, "");
 		thestring = insert_string_if_entry(GTK_ENTRY(imdg->dg->entry[3]), cap("USEMAP"), thestring, NULL);
@@ -212,7 +212,7 @@ image_insert_dialogok_lcb(GtkWidget * widget, Timage_diag * imdg)
 			insert_string_if_combobox(GTK_COMBO_BOX(imdg->dg->combo[0]), cap("ALIGN"), thestring, NULL);
 		thestring = insert_string_if_entry(GTK_ENTRY(imdg->dg->entry[4]), NULL, thestring, NULL);
 
-		finalstring = g_strconcat(thestring, (main_v->props.xhtml == 1) ? " />" : ">", NULL);
+		finalstring = g_strconcat(thestring, get_curlang_option_value(imdg->dg->bfwin, self_close_singleton_tags) ? " />" : ">", NULL);
 		g_free(thestring);
 
 		if (imdg->dg->range.end == -1) {
@@ -1050,8 +1050,8 @@ multi_thumbnail_dialog(Tbfwin * bfwin)
 	mtd->bfwin = bfwin;
 	mtd->document = bfwin->current_document;
 	mtd->win =
-		window_full2(_("Multi thumbnail"), GTK_WIN_POS_MOUSE, 5, G_CALLBACK(mt_dialog_destroy), mtd, TRUE,
-					 NULL);
+		window_full2(_("Multi thumbnail"), GTK_WIN_POS_CENTER, 5, G_CALLBACK(mt_dialog_destroy), mtd, TRUE,
+					 bfwin->main_window);
 	vbox = gtk_vbox_new(FALSE, 5);
 	gtk_container_add(GTK_CONTAINER(mtd->win), vbox);
 
