@@ -189,13 +189,15 @@ snippets_connect_accelerators_from_doc(Tsnippetswin * snw, xmlNodePtr cur, GtkAc
 					hcbdata->snw = snw;
 					hcbdata->cur = cur;
 					DEBUG_MSG
-						("snippets_connect_accelerators_from_doc, connecting accelerator %s to data %p\n",
-						 accelerator, hcbdata);
+						("snippets_connect_accelerators_from_doc, connecting accelerator %s to data %p, and add to accel_group %p\n",
+						 accelerator, hcbdata, accel_group);
 					closure =
 						g_cclosure_new(G_CALLBACK(snippets_accelerator_activated_lcb), hcbdata,
 									   (GClosureNotify) accelerator_cbdata_free);
 					gtk_accel_group_connect(accel_group, key, mod, GTK_ACCEL_VISIBLE, closure);
-					g_object_watch_closure(G_OBJECT(snw->view), closure);
+					g_object_watch_closure(G_OBJECT(snw->bfwin->main_window), closure);
+				} else {
+					g_print("Invalid shortcut key %s found in snippets library\n", accelerator);
 				}
 				xmlFree(accelerator);
 			}
@@ -215,10 +217,12 @@ snippets_rebuild_accelerators(void)
 		Tsnippetswin *snw = g_hash_table_lookup(snippets_v.lookup, bfwin);
 		if (!snw)
 			continue;
+		DEBUG_MSG("remove accel_group from bfwin %p\n",bfwin);
 		gtk_window_remove_accel_group(GTK_WINDOW(bfwin->main_window), snw->accel_group);
 		g_object_unref(G_OBJECT(snw->accel_group));
 
 		snw->accel_group = gtk_accel_group_new();
+		DEBUG_MSG("add new accel_group %p to bfwin %p\n",snw->accel_group,bfwin);
 		gtk_window_add_accel_group(GTK_WINDOW(bfwin->main_window), snw->accel_group);
 		if (snippets_v.doc) {
 			xmlNodePtr cur = xmlDocGetRootElement(snippets_v.doc);
@@ -265,7 +269,12 @@ snippets_show_as_menu(Tsnippetswin * snw, gboolean enable)
 		if (!snw->snippetsmenu) {
 			gint width = gdk_screen_get_width(gtk_window_get_screen(GTK_WINDOW(snw->bfwin->main_window)));
 			snw->snippetsmenu = snippets_menu_new(width);
+#if !GTK_CHECK_VERSION(3,4,0)
 			gtk_box_pack_start(GTK_BOX(snw->bfwin->toolbarbox), snw->snippetsmenu, FALSE, FALSE, 0);
+#else
+			gtk_widget_set_name(GTK_WIDGET(snw->snippetsmenu), "snippets_menu_bar");
+			gtk_container_add(GTK_CONTAINER(snw->bfwin->toolbarbox),snw->snippetsmenu);
+#endif
 			gtk_widget_show(snw->snippetsmenu);	/* show is required such that the size requests are accurate */
 			snippets_menu_set_model((SnippetsMenu *) snw->snippetsmenu, (GtkTreeModel *) snippets_v.store,
 									snippetsmenu_cb, snw, TITLE_COLUMN, NODE_COLUMN);
@@ -551,13 +560,13 @@ snippets_search(GtkTreeModel *model,gint column,const gchar *key,GtkTreeIter *it
 	xmlNodePtr node;
 	gchar *tmp=NULL, *title=NULL;
 	gboolean retval = TRUE;
-	
+
 	gtk_tree_model_get(model, iter, NODE_COLUMN, &node, TITLE_COLUMN, &title, -1);
 	if (title && strcasestr(title, key)!= NULL) {
 		retval = FALSE;
 	}
 	g_free(title);
-		
+
 	if (node) {
 		xmlChar *type = xmlGetProp(node, (const xmlChar *) "type");
 		if (type && xmlStrEqual(type, (const xmlChar *) "insert")) {
@@ -763,6 +772,7 @@ popup_menu_set_accelerator(GtkAction * action, gpointer user_data)
 			} else {
 				xmlSetProp(snw->lastclickednode, (const xmlChar *) "accelerator", (const xmlChar *) accel);
 			}
+			DEBUG_MSG("popup_menu_set_accelerator, call snippets_rebuild_accelerators()\n");
 			snippets_rebuild_accelerators();
 			g_idle_add(snippets_store_lcb, NULL);
 			g_free(accel);
@@ -826,7 +836,7 @@ static const GtkActionEntry snippets_actions[] = {
 static const GtkToggleActionEntry snippets_toggle_actions[] = {
 	{"ShowAsMenu", NULL, N_("_Show as menu"), NULL, N_("Show snippets menu"),
 	 G_CALLBACK(popup_menu_show_as_menu)},
-	{"ViewSnippetsMenu", NULL, N_("S_nippets Menu"), NULL, NULL, G_CALLBACK(popup_menu_show_as_menu), TRUE},
+	{"ViewSnippetsMenu", NULL, N_("S_nippets Menu"), NULL, NULL, G_CALLBACK(popup_menu_show_as_menu), FALSE},
 };
 
 void
